==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/connect/ExternalConfigurationEnvFluent.java <==
package io.strimzi.api.kafka.model.connect;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ExternalConfigurationEnvFluent<A extends ExternalConfigurationEnvFluent<A>> extends Fluent<A>{


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildValueFrom instead.
 * @return The buildable object.
 */
@Deprecated public ExternalConfigurationEnvVarSource getValueFrom();
    public ExternalConfigurationEnvVarSource buildValueFrom();
    public A withValueFrom(ExternalConfigurationEnvVarSource valueFrom);
    public Boolean hasValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> withNewValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> withNewValueFromLike(ExternalConfigurationEnvVarSource item);
    public ExternalConfigurationEnvFluent.ValueFromNested<A> editValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> editOrNewValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> editOrNewValueFromLike(ExternalConfigurationEnvVarSource item);

    public interface ValueFromNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalConfigurationEnvVarSourceFluent<ExternalConfigurationEnvFluent.ValueFromNested<N>>{

        
    public N and();    public N endValueFrom();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/connect/ExternalConfigurationEnvFluent.java <==
package io.strimzi.api.kafka.model.connect;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ExternalConfigurationEnvFluent<A extends ExternalConfigurationEnvFluent<A>> extends Fluent<A> {


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    
/**
 * This method has been deprecated, please use method buildValueFrom instead.
 * @return The buildable object.
 */
@Deprecated public ExternalConfigurationEnvVarSource getValueFrom();
    public ExternalConfigurationEnvVarSource buildValueFrom();
    public A withValueFrom(ExternalConfigurationEnvVarSource valueFrom);
    public Boolean hasValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> withNewValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> withNewValueFromLike(ExternalConfigurationEnvVarSource item);
    public ExternalConfigurationEnvFluent.ValueFromNested<A> editValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> editOrNewValueFrom();
    public ExternalConfigurationEnvFluent.ValueFromNested<A> editOrNewValueFromLike(ExternalConfigurationEnvVarSource item);
    public interface ValueFromNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalConfigurationEnvVarSourceFluent<ExternalConfigurationEnvFluent.ValueFromNested<N>> {

            public N and();
            public N endValueFrom();    }


}
